import os
import numpy as np
from .simulate_dag import simulate_SummaryDAG
from .simulate_dist import Dist

def generateData(exps = 10, graph_type = 'ER', d = 20, s0=20, s1=10, s2=5, n = 1000, gunc='linear', func='linear', noiseType = 'Gauss'):
    
    DAGname='{}_{}_{}_{}_{}'.format(graph_type, d, s0, s1, s2)
    savePath = '/DAG_{}/{}({})_{}_{}/'.format(DAGname, noiseType, n, gunc, func)

    norm = False if gunc == 'sin' or func == 'sin' else True

    for exp in range(exps):
        expPath = f'./Data/{savePath}/{exp}/'
        os.makedirs(os.path.dirname(expPath), exist_ok=True)

        SummaryDAG, AutoREG_1st, AutoREG_2nd = simulate_SummaryDAG(d, s0, s1, s2, graph_type)

        np.save(expPath+"adjacency.npy", SummaryDAG)
        np.savetxt(expPath+'SummaryDAG.csv', SummaryDAG, delimiter=',', fmt='%.0f')
        np.savetxt(expPath+'AutoREG_1st.csv', AutoREG_1st, delimiter=',', fmt='%.0f')
        np.savetxt(expPath+'AutoREG_2nd.csv', AutoREG_2nd, delimiter=',', fmt='%.0f')
        
        teacher = Dist(d, SummaryDAG, AutoREG_1st, AutoREG_2nd, noise_type = [noiseType]*4, gunc=gunc, func=func, norm=norm)
        Datas, Interventions = teacher.sample(expPath, n)

    return SummaryDAG, AutoREG_1st, AutoREG_2nd, Datas, Interventions, savePath
